==> haskell-cheapskate-0.1.0.5-68-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cheapskate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cheapskate
version: 0.1.0.5
id: cheapskate-0.1.0.5-LroonCvIxWr5h94vL007ZN
key: cheapskate-0.1.0.5-LroonCvIxWr5h94vL007ZN
license: BSD3
copyright: (C) 2012-2013 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: http://github.com/jgm/cheapskate
synopsis: Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.
    .
    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.
category: Text
author: John MacFarlane
exposed: True
exposed-modules:
    Cheapskate Cheapskate.Parse Cheapskate.Types Cheapskate.Html
hidden-modules: Cheapskate.Util Cheapskate.Inlines
                Cheapskate.ParserCombinators Paths_cheapskate
abi: 54e77c97aa0ed0c622ed90a1fd9743ae
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/cheapskate-0.1.0.5
library-dirs: /usr/lib/ghc-8.0.2/site-local/cheapskate-0.1.0.5
dynamic-library-dirs: /usr/lib/x86_64-linux-ghc-8.0.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/cheapskate-0.1.0.5
hs-libraries: HScheapskate-0.1.0.5-LroonCvIxWr5h94vL007ZN
depends:
    base-4.9.1.0 blaze-html-0.8.1.3-EHw0sCLFL6JKZx2lFkE5O8
    containers-0.5.7.1 data-default-0.7.1.1-CyM3k1XLfwb41mPgt03rCT
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 syb-0.6-IcoSwlPi2Nx4zSqMmorFPS
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    uniplate-1.6.12-N3KU2vBtqpinRklGR4lS
    xss-sanitize-0.3.5.7-wQvcGenZuzFpS72xo3Du2
haddock-interfaces: /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html: /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cheapskate-0.1.0.5-75-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cheapskate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cheapskate
version: 0.1.0.5
id: cheapskate-0.1.0.5-KV6DmPwqe36ESre8KtKsqW
key: cheapskate-0.1.0.5-KV6DmPwqe36ESre8KtKsqW
license: BSD3
copyright: (C) 2012-2013 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: http://github.com/jgm/cheapskate
synopsis: Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.
    .
    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.
category: Text
author: John MacFarlane
exposed: True
exposed-modules:
    Cheapskate Cheapskate.Parse Cheapskate.Types Cheapskate.Html
hidden-modules: Cheapskate.Util Cheapskate.Inlines
                Cheapskate.ParserCombinators Paths_cheapskate
abi: d189d26ec7d3ab7e918e10f07ead8bea
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/cheapskate-0.1.0.5
library-dirs: /usr/lib/ghc-8.0.2/site-local/cheapskate-0.1.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/cheapskate-0.1.0.5
hs-libraries: HScheapskate-0.1.0.5-KV6DmPwqe36ESre8KtKsqW
depends:
    base-4.9.1.0 blaze-html-0.8.1.3-EHw0sCLFL6JKZx2lFkE5O8
    containers-0.5.7.1 data-default-0.7.1.1-BNa3MzH41nV77yjS9K2Umq
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 syb-0.6-IcoSwlPi2Nx4zSqMmorFPS
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    uniplate-1.6.12-BnRcpBOCdUXBfQOzOuZrJE
    xss-sanitize-0.3.5.7-JtwY0h7AXl57kDNiQenhrv
haddock-interfaces: /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html: /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
